#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainFinanceRiskApplyResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainFinanceRiskApplyResponse, self).__init__()
        self._out_risk_id = None
        self._risk_info = None

    @property
    def out_risk_id(self):
        return self._out_risk_id

    @out_risk_id.setter
    def out_risk_id(self, value):
        self._out_risk_id = value
    @property
    def risk_info(self):
        return self._risk_info

    @risk_info.setter
    def risk_info(self, value):
        self._risk_info = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainFinanceRiskApplyResponse, self).parse_response_content(response_content)
        if 'out_risk_id' in response:
            self.out_risk_id = response['out_risk_id']
        if 'risk_info' in response:
            self.risk_info = response['risk_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchBoxServiceInfo(object):

    def __init__(self):
        self._service_category_code = None
        self._service_category_name = None
        self._service_code = None
        self._service_name = None

    @property
    def service_category_code(self):
        return self._service_category_code

    @service_category_code.setter
    def service_category_code(self, value):
        self._service_category_code = value
    @property
    def service_category_name(self):
        return self._service_category_name

    @service_category_name.setter
    def service_category_name(self, value):
        self._service_category_name = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.service_category_code:
            if hasattr(self.service_category_code, 'to_alipay_dict'):
                params['service_category_code'] = self.service_category_code.to_alipay_dict()
            else:
                params['service_category_code'] = self.service_category_code
        if self.service_category_name:
            if hasattr(self.service_category_name, 'to_alipay_dict'):
                params['service_category_name'] = self.service_category_name.to_alipay_dict()
            else:
                params['service_category_name'] = self.service_category_name
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.service_name:
            if hasattr(self.service_name, 'to_alipay_dict'):
                params['service_name'] = self.service_name.to_alipay_dict()
            else:
                params['service_name'] = self.service_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchBoxServiceInfo()
        if 'service_category_code' in d:
            o.service_category_code = d['service_category_code']
        if 'service_category_name' in d:
            o.service_category_name = d['service_category_name']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'service_name' in d:
            o.service_name = d['service_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTerminalPowerbankCreateModel(object):

    def __init__(self):
        self._latitude = None
        self._longitude = None
        self._proxy_id = None
        self._sn = None

    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def proxy_id(self):
        return self._proxy_id

    @proxy_id.setter
    def proxy_id(self, value):
        self._proxy_id = value
    @property
    def sn(self):
        return self._sn

    @sn.setter
    def sn(self, value):
        self._sn = value


    def to_alipay_dict(self):
        params = dict()
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.proxy_id:
            if hasattr(self.proxy_id, 'to_alipay_dict'):
                params['proxy_id'] = self.proxy_id.to_alipay_dict()
            else:
                params['proxy_id'] = self.proxy_id
        if self.sn:
            if hasattr(self.sn, 'to_alipay_dict'):
                params['sn'] = self.sn.to_alipay_dict()
            else:
                params['sn'] = self.sn
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTerminalPowerbankCreateModel()
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'proxy_id' in d:
            o.proxy_id = d['proxy_id']
        if 'sn' in d:
            o.sn = d['sn']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CloudbusTotalOdItem(object):

    def __init__(self):
        self._code = None
        self._message = None
        self._totalod = None
        self._weekend_od = None
        self._workday_od = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value
    @property
    def totalod(self):
        return self._totalod

    @totalod.setter
    def totalod(self, value):
        self._totalod = value
    @property
    def weekend_od(self):
        return self._weekend_od

    @weekend_od.setter
    def weekend_od(self, value):
        self._weekend_od = value
    @property
    def workday_od(self):
        return self._workday_od

    @workday_od.setter
    def workday_od(self, value):
        self._workday_od = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.message:
            if hasattr(self.message, 'to_alipay_dict'):
                params['message'] = self.message.to_alipay_dict()
            else:
                params['message'] = self.message
        if self.totalod:
            if hasattr(self.totalod, 'to_alipay_dict'):
                params['totalod'] = self.totalod.to_alipay_dict()
            else:
                params['totalod'] = self.totalod
        if self.weekend_od:
            if hasattr(self.weekend_od, 'to_alipay_dict'):
                params['weekend_od'] = self.weekend_od.to_alipay_dict()
            else:
                params['weekend_od'] = self.weekend_od
        if self.workday_od:
            if hasattr(self.workday_od, 'to_alipay_dict'):
                params['workday_od'] = self.workday_od.to_alipay_dict()
            else:
                params['workday_od'] = self.workday_od
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CloudbusTotalOdItem()
        if 'code' in d:
            o.code = d['code']
        if 'message' in d:
            o.message = d['message']
        if 'totalod' in d:
            o.totalod = d['totalod']
        if 'weekend_od' in d:
            o.weekend_od = d['weekend_od']
        if 'workday_od' in d:
            o.workday_od = d['workday_od']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PromoAccessBaseCatalogVO import PromoAccessBaseCatalogVO
from alipay.aop.api.domain.PromoContentApiSchemaVO import PromoContentApiSchemaVO


class AlipayOpenAppServicePromotemplateQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppServicePromotemplateQueryResponse, self).__init__()
        self._promo_access_catalog_vos = None
        self._promo_booth_desc = None
        self._promo_booth_desc_url = None
        self._promo_booth_entity_num_type = None
        self._promo_booth_entity_type = None
        self._promo_booth_id = None
        self._promo_booth_name = None
        self._promo_content_api_schema_vos = None

    @property
    def promo_access_catalog_vos(self):
        return self._promo_access_catalog_vos

    @promo_access_catalog_vos.setter
    def promo_access_catalog_vos(self, value):
        if isinstance(value, list):
            self._promo_access_catalog_vos = list()
            for i in value:
                if isinstance(i, PromoAccessBaseCatalogVO):
                    self._promo_access_catalog_vos.append(i)
                else:
                    self._promo_access_catalog_vos.append(PromoAccessBaseCatalogVO.from_alipay_dict(i))
    @property
    def promo_booth_desc(self):
        return self._promo_booth_desc

    @promo_booth_desc.setter
    def promo_booth_desc(self, value):
        self._promo_booth_desc = value
    @property
    def promo_booth_desc_url(self):
        return self._promo_booth_desc_url

    @promo_booth_desc_url.setter
    def promo_booth_desc_url(self, value):
        self._promo_booth_desc_url = value
    @property
    def promo_booth_entity_num_type(self):
        return self._promo_booth_entity_num_type

    @promo_booth_entity_num_type.setter
    def promo_booth_entity_num_type(self, value):
        self._promo_booth_entity_num_type = value
    @property
    def promo_booth_entity_type(self):
        return self._promo_booth_entity_type

    @promo_booth_entity_type.setter
    def promo_booth_entity_type(self, value):
        self._promo_booth_entity_type = value
    @property
    def promo_booth_id(self):
        return self._promo_booth_id

    @promo_booth_id.setter
    def promo_booth_id(self, value):
        self._promo_booth_id = value
    @property
    def promo_booth_name(self):
        return self._promo_booth_name

    @promo_booth_name.setter
    def promo_booth_name(self, value):
        self._promo_booth_name = value
    @property
    def promo_content_api_schema_vos(self):
        return self._promo_content_api_schema_vos

    @promo_content_api_schema_vos.setter
    def promo_content_api_schema_vos(self, value):
        if isinstance(value, list):
            self._promo_content_api_schema_vos = list()
            for i in value:
                if isinstance(i, PromoContentApiSchemaVO):
                    self._promo_content_api_schema_vos.append(i)
                else:
                    self._promo_content_api_schema_vos.append(PromoContentApiSchemaVO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppServicePromotemplateQueryResponse, self).parse_response_content(response_content)
        if 'promo_access_catalog_vos' in response:
            self.promo_access_catalog_vos = response['promo_access_catalog_vos']
        if 'promo_booth_desc' in response:
            self.promo_booth_desc = response['promo_booth_desc']
        if 'promo_booth_desc_url' in response:
            self.promo_booth_desc_url = response['promo_booth_desc_url']
        if 'promo_booth_entity_num_type' in response:
            self.promo_booth_entity_num_type = response['promo_booth_entity_num_type']
        if 'promo_booth_entity_type' in response:
            self.promo_booth_entity_type = response['promo_booth_entity_type']
        if 'promo_booth_id' in response:
            self.promo_booth_id = response['promo_booth_id']
        if 'promo_booth_name' in response:
            self.promo_booth_name = response['promo_booth_name']
        if 'promo_content_api_schema_vos' in response:
            self.promo_content_api_schema_vos = response['promo_content_api_schema_vos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommercePetFileQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommercePetFileQueryResponse, self).__init__()
        self._birth_date = None
        self._breed = None
        self._category = None
        self._expelled_flag = None
        self._id = None
        self._name = None
        self._pet_certify = None
        self._photo = None
        self._sex = None
        self._sterilization_flag = None
        self._vaccines_flag = None

    @property
    def birth_date(self):
        return self._birth_date

    @birth_date.setter
    def birth_date(self, value):
        self._birth_date = value
    @property
    def breed(self):
        return self._breed

    @breed.setter
    def breed(self, value):
        self._breed = value
    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def expelled_flag(self):
        return self._expelled_flag

    @expelled_flag.setter
    def expelled_flag(self, value):
        self._expelled_flag = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def pet_certify(self):
        return self._pet_certify

    @pet_certify.setter
    def pet_certify(self, value):
        self._pet_certify = value
    @property
    def photo(self):
        return self._photo

    @photo.setter
    def photo(self, value):
        if isinstance(value, list):
            self._photo = list()
            for i in value:
                self._photo.append(i)
    @property
    def sex(self):
        return self._sex

    @sex.setter
    def sex(self, value):
        self._sex = value
    @property
    def sterilization_flag(self):
        return self._sterilization_flag

    @sterilization_flag.setter
    def sterilization_flag(self, value):
        self._sterilization_flag = value
    @property
    def vaccines_flag(self):
        return self._vaccines_flag

    @vaccines_flag.setter
    def vaccines_flag(self, value):
        self._vaccines_flag = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommercePetFileQueryResponse, self).parse_response_content(response_content)
        if 'birth_date' in response:
            self.birth_date = response['birth_date']
        if 'breed' in response:
            self.breed = response['breed']
        if 'category' in response:
            self.category = response['category']
        if 'expelled_flag' in response:
            self.expelled_flag = response['expelled_flag']
        if 'id' in response:
            self.id = response['id']
        if 'name' in response:
            self.name = response['name']
        if 'pet_certify' in response:
            self.pet_certify = response['pet_certify']
        if 'photo' in response:
            self.photo = response['photo']
        if 'sex' in response:
            self.sex = response['sex']
        if 'sterilization_flag' in response:
            self.sterilization_flag = response['sterilization_flag']
        if 'vaccines_flag' in response:
            self.vaccines_flag = response['vaccines_flag']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PoCumAccruedBalanceAmtDTO import PoCumAccruedBalanceAmtDTO


class AlipayBossFncGfaccruedprodCumpoaccbalamtQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossFncGfaccruedprodCumpoaccbalamtQueryResponse, self).__init__()
        self._result_data = None

    @property
    def result_data(self):
        return self._result_data

    @result_data.setter
    def result_data(self, value):
        if isinstance(value, PoCumAccruedBalanceAmtDTO):
            self._result_data = value
        else:
            self._result_data = PoCumAccruedBalanceAmtDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayBossFncGfaccruedprodCumpoaccbalamtQueryResponse, self).parse_response_content(response_content)
        if 'result_data' in response:
            self.result_data = response['result_data']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneMobileScreenRefundModel(object):

    def __init__(self):
        self._channel = None
        self._policy_no = None

    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def policy_no(self):
        return self._policy_no

    @policy_no.setter
    def policy_no(self, value):
        self._policy_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.policy_no:
            if hasattr(self.policy_no, 'to_alipay_dict'):
                params['policy_no'] = self.policy_no.to_alipay_dict()
            else:
                params['policy_no'] = self.policy_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneMobileScreenRefundModel()
        if 'channel' in d:
            o.channel = d['channel']
        if 'policy_no' in d:
            o.policy_no = d['policy_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AntArchiveIdentityCertificate import AntArchiveIdentityCertificate
from alipay.aop.api.domain.AntArchiveIdentityCertificate import AntArchiveIdentityCertificate


class AlipayUserAntarchiveIdentityrelationAddModel(object):

    def __init__(self):
        self._ext_info = None
        self._rel_biz_type = None
        self._rel_type = None
        self._source_identity_certificate = None
        self._target_identity_certificate = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def rel_biz_type(self):
        return self._rel_biz_type

    @rel_biz_type.setter
    def rel_biz_type(self, value):
        self._rel_biz_type = value
    @property
    def rel_type(self):
        return self._rel_type

    @rel_type.setter
    def rel_type(self, value):
        self._rel_type = value
    @property
    def source_identity_certificate(self):
        return self._source_identity_certificate

    @source_identity_certificate.setter
    def source_identity_certificate(self, value):
        if isinstance(value, AntArchiveIdentityCertificate):
            self._source_identity_certificate = value
        else:
            self._source_identity_certificate = AntArchiveIdentityCertificate.from_alipay_dict(value)
    @property
    def target_identity_certificate(self):
        return self._target_identity_certificate

    @target_identity_certificate.setter
    def target_identity_certificate(self, value):
        if isinstance(value, AntArchiveIdentityCertificate):
            self._target_identity_certificate = value
        else:
            self._target_identity_certificate = AntArchiveIdentityCertificate.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.rel_biz_type:
            if hasattr(self.rel_biz_type, 'to_alipay_dict'):
                params['rel_biz_type'] = self.rel_biz_type.to_alipay_dict()
            else:
                params['rel_biz_type'] = self.rel_biz_type
        if self.rel_type:
            if hasattr(self.rel_type, 'to_alipay_dict'):
                params['rel_type'] = self.rel_type.to_alipay_dict()
            else:
                params['rel_type'] = self.rel_type
        if self.source_identity_certificate:
            if hasattr(self.source_identity_certificate, 'to_alipay_dict'):
                params['source_identity_certificate'] = self.source_identity_certificate.to_alipay_dict()
            else:
                params['source_identity_certificate'] = self.source_identity_certificate
        if self.target_identity_certificate:
            if hasattr(self.target_identity_certificate, 'to_alipay_dict'):
                params['target_identity_certificate'] = self.target_identity_certificate.to_alipay_dict()
            else:
                params['target_identity_certificate'] = self.target_identity_certificate
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAntarchiveIdentityrelationAddModel()
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'rel_biz_type' in d:
            o.rel_biz_type = d['rel_biz_type']
        if 'rel_type' in d:
            o.rel_type = d['rel_type']
        if 'source_identity_certificate' in d:
            o.source_identity_certificate = d['source_identity_certificate']
        if 'target_identity_certificate' in d:
            o.target_identity_certificate = d['target_identity_certificate']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BarcodeInfoVO(object):

    def __init__(self):
        self._barcode = None
        self._barcode_type = None

    @property
    def barcode(self):
        return self._barcode

    @barcode.setter
    def barcode(self, value):
        self._barcode = value
    @property
    def barcode_type(self):
        return self._barcode_type

    @barcode_type.setter
    def barcode_type(self, value):
        self._barcode_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.barcode:
            if hasattr(self.barcode, 'to_alipay_dict'):
                params['barcode'] = self.barcode.to_alipay_dict()
            else:
                params['barcode'] = self.barcode
        if self.barcode_type:
            if hasattr(self.barcode_type, 'to_alipay_dict'):
                params['barcode_type'] = self.barcode_type.to_alipay_dict()
            else:
                params['barcode_type'] = self.barcode_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BarcodeInfoVO()
        if 'barcode' in d:
            o.barcode = d['barcode']
        if 'barcode_type' in d:
            o.barcode_type = d['barcode_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InsPolicy import InsPolicy


class AlipayInsUnderwriteUserPolicyQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsUnderwriteUserPolicyQueryResponse, self).__init__()
        self._policys = None
        self._total = None

    @property
    def policys(self):
        return self._policys

    @policys.setter
    def policys(self, value):
        if isinstance(value, list):
            self._policys = list()
            for i in value:
                if isinstance(i, InsPolicy):
                    self._policys.append(i)
                else:
                    self._policys.append(InsPolicy.from_alipay_dict(i))
    @property
    def total(self):
        return self._total

    @total.setter
    def total(self, value):
        self._total = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsUnderwriteUserPolicyQueryResponse, self).parse_response_content(response_content)
        if 'policys' in response:
            self.policys = response['policys']
        if 'total' in response:
            self.total = response['total']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySocialAntiepTaskFinishModel(object):

    def __init__(self):
        self._condition_for_variable_award = None
        self._finish_business_info = None
        self._request_mode = None
        self._request_type = None
        self._scene_code = None
        self._source = None
        self._task_token = None
        self._task_type = None
        self._unique_id = None
        self._zone_id = None

    @property
    def condition_for_variable_award(self):
        return self._condition_for_variable_award

    @condition_for_variable_award.setter
    def condition_for_variable_award(self, value):
        self._condition_for_variable_award = value
    @property
    def finish_business_info(self):
        return self._finish_business_info

    @finish_business_info.setter
    def finish_business_info(self, value):
        self._finish_business_info = value
    @property
    def request_mode(self):
        return self._request_mode

    @request_mode.setter
    def request_mode(self, value):
        self._request_mode = value
    @property
    def request_type(self):
        return self._request_type

    @request_type.setter
    def request_type(self, value):
        self._request_type = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def task_token(self):
        return self._task_token

    @task_token.setter
    def task_token(self, value):
        self._task_token = value
    @property
    def task_type(self):
        return self._task_type

    @task_type.setter
    def task_type(self, value):
        self._task_type = value
    @property
    def unique_id(self):
        return self._unique_id

    @unique_id.setter
    def unique_id(self, value):
        self._unique_id = value
    @property
    def zone_id(self):
        return self._zone_id

    @zone_id.setter
    def zone_id(self, value):
        self._zone_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.condition_for_variable_award:
            if hasattr(self.condition_for_variable_award, 'to_alipay_dict'):
                params['condition_for_variable_award'] = self.condition_for_variable_award.to_alipay_dict()
            else:
                params['condition_for_variable_award'] = self.condition_for_variable_award
        if self.finish_business_info:
            if hasattr(self.finish_business_info, 'to_alipay_dict'):
                params['finish_business_info'] = self.finish_business_info.to_alipay_dict()
            else:
                params['finish_business_info'] = self.finish_business_info
        if self.request_mode:
            if hasattr(self.request_mode, 'to_alipay_dict'):
                params['request_mode'] = self.request_mode.to_alipay_dict()
            else:
                params['request_mode'] = self.request_mode
        if self.request_type:
            if hasattr(self.request_type, 'to_alipay_dict'):
                params['request_type'] = self.request_type.to_alipay_dict()
            else:
                params['request_type'] = self.request_type
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.task_token:
            if hasattr(self.task_token, 'to_alipay_dict'):
                params['task_token'] = self.task_token.to_alipay_dict()
            else:
                params['task_token'] = self.task_token
        if self.task_type:
            if hasattr(self.task_type, 'to_alipay_dict'):
                params['task_type'] = self.task_type.to_alipay_dict()
            else:
                params['task_type'] = self.task_type
        if self.unique_id:
            if hasattr(self.unique_id, 'to_alipay_dict'):
                params['unique_id'] = self.unique_id.to_alipay_dict()
            else:
                params['unique_id'] = self.unique_id
        if self.zone_id:
            if hasattr(self.zone_id, 'to_alipay_dict'):
                params['zone_id'] = self.zone_id.to_alipay_dict()
            else:
                params['zone_id'] = self.zone_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySocialAntiepTaskFinishModel()
        if 'condition_for_variable_award' in d:
            o.condition_for_variable_award = d['condition_for_variable_award']
        if 'finish_business_info' in d:
            o.finish_business_info = d['finish_business_info']
        if 'request_mode' in d:
            o.request_mode = d['request_mode']
        if 'request_type' in d:
            o.request_type = d['request_type']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'source' in d:
            o.source = d['source']
        if 'task_token' in d:
            o.task_token = d['task_token']
        if 'task_type' in d:
            o.task_type = d['task_type']
        if 'unique_id' in d:
            o.unique_id = d['unique_id']
        if 'zone_id' in d:
            o.zone_id = d['zone_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BaseCrossborderMerchantInfo import BaseCrossborderMerchantInfo


class AlipayFincoreComplianceCrossborderMerchantBatchqueryModel(object):

    def __init__(self):
        self._biz_source = None
        self._org_list = None
        self._out_biz_no = None
        self._total = None

    @property
    def biz_source(self):
        return self._biz_source

    @biz_source.setter
    def biz_source(self, value):
        self._biz_source = value
    @property
    def org_list(self):
        return self._org_list

    @org_list.setter
    def org_list(self, value):
        if isinstance(value, list):
            self._org_list = list()
            for i in value:
                if isinstance(i, BaseCrossborderMerchantInfo):
                    self._org_list.append(i)
                else:
                    self._org_list.append(BaseCrossborderMerchantInfo.from_alipay_dict(i))
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def total(self):
        return self._total

    @total.setter
    def total(self, value):
        self._total = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_source:
            if hasattr(self.biz_source, 'to_alipay_dict'):
                params['biz_source'] = self.biz_source.to_alipay_dict()
            else:
                params['biz_source'] = self.biz_source
        if self.org_list:
            if isinstance(self.org_list, list):
                for i in range(0, len(self.org_list)):
                    element = self.org_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.org_list[i] = element.to_alipay_dict()
            if hasattr(self.org_list, 'to_alipay_dict'):
                params['org_list'] = self.org_list.to_alipay_dict()
            else:
                params['org_list'] = self.org_list
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.total:
            if hasattr(self.total, 'to_alipay_dict'):
                params['total'] = self.total.to_alipay_dict()
            else:
                params['total'] = self.total
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFincoreComplianceCrossborderMerchantBatchqueryModel()
        if 'biz_source' in d:
            o.biz_source = d['biz_source']
        if 'org_list' in d:
            o.org_list = d['org_list']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'total' in d:
            o.total = d['total']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OuterTargetingItem import OuterTargetingItem


class OuterGroup(object):

    def __init__(self):
        self._conversion_id_list = None
        self._conversion_type = None
        self._extend_info = None
        self._group_charge = None
        self._group_id = None
        self._group_name = None
        self._group_outer_id = None
        self._group_status = None
        self._item_id_list = None
        self._ocpx_switch = None
        self._plan_outer_id = None
        self._target_cpa = None
        self._targeting_list = None
        self._time_option = None
        self._time_schema = None

    @property
    def conversion_id_list(self):
        return self._conversion_id_list

    @conversion_id_list.setter
    def conversion_id_list(self, value):
        if isinstance(value, list):
            self._conversion_id_list = list()
            for i in value:
                self._conversion_id_list.append(i)
    @property
    def conversion_type(self):
        return self._conversion_type

    @conversion_type.setter
    def conversion_type(self, value):
        self._conversion_type = value
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def group_charge(self):
        return self._group_charge

    @group_charge.setter
    def group_charge(self, value):
        self._group_charge = value
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def group_name(self):
        return self._group_name

    @group_name.setter
    def group_name(self, value):
        self._group_name = value
    @property
    def group_outer_id(self):
        return self._group_outer_id

    @group_outer_id.setter
    def group_outer_id(self, value):
        self._group_outer_id = value
    @property
    def group_status(self):
        return self._group_status

    @group_status.setter
    def group_status(self, value):
        self._group_status = value
    @property
    def item_id_list(self):
        return self._item_id_list

    @item_id_list.setter
    def item_id_list(self, value):
        if isinstance(value, list):
            self._item_id_list = list()
            for i in value:
                self._item_id_list.append(i)
    @property
    def ocpx_switch(self):
        return self._ocpx_switch

    @ocpx_switch.setter
    def ocpx_switch(self, value):
        self._ocpx_switch = value
    @property
    def plan_outer_id(self):
        return self._plan_outer_id

    @plan_outer_id.setter
    def plan_outer_id(self, value):
        self._plan_outer_id = value
    @property
    def target_cpa(self):
        return self._target_cpa

    @target_cpa.setter
    def target_cpa(self, value):
        self._target_cpa = value
    @property
    def targeting_list(self):
        return self._targeting_list

    @targeting_list.setter
    def targeting_list(self, value):
        if isinstance(value, list):
            self._targeting_list = list()
            for i in value:
                if isinstance(i, OuterTargetingItem):
                    self._targeting_list.append(i)
                else:
                    self._targeting_list.append(OuterTargetingItem.from_alipay_dict(i))
    @property
    def time_option(self):
        return self._time_option

    @time_option.setter
    def time_option(self, value):
        self._time_option = value
    @property
    def time_schema(self):
        return self._time_schema

    @time_schema.setter
    def time_schema(self, value):
        self._time_schema = value


    def to_alipay_dict(self):
        params = dict()
        if self.conversion_id_list:
            if isinstance(self.conversion_id_list, list):
                for i in range(0, len(self.conversion_id_list)):
                    element = self.conversion_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.conversion_id_list[i] = element.to_alipay_dict()
            if hasattr(self.conversion_id_list, 'to_alipay_dict'):
                params['conversion_id_list'] = self.conversion_id_list.to_alipay_dict()
            else:
                params['conversion_id_list'] = self.conversion_id_list
        if self.conversion_type:
            if hasattr(self.conversion_type, 'to_alipay_dict'):
                params['conversion_type'] = self.conversion_type.to_alipay_dict()
            else:
                params['conversion_type'] = self.conversion_type
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.group_charge:
            if hasattr(self.group_charge, 'to_alipay_dict'):
                params['group_charge'] = self.group_charge.to_alipay_dict()
            else:
                params['group_charge'] = self.group_charge
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.group_name:
            if hasattr(self.group_name, 'to_alipay_dict'):
                params['group_name'] = self.group_name.to_alipay_dict()
            else:
                params['group_name'] = self.group_name
        if self.group_outer_id:
            if hasattr(self.group_outer_id, 'to_alipay_dict'):
                params['group_outer_id'] = self.group_outer_id.to_alipay_dict()
            else:
                params['group_outer_id'] = self.group_outer_id
        if self.group_status:
            if hasattr(self.group_status, 'to_alipay_dict'):
                params['group_status'] = self.group_status.to_alipay_dict()
            else:
                params['group_status'] = self.group_status
        if self.item_id_list:
            if isinstance(self.item_id_list, list):
                for i in range(0, len(self.item_id_list)):
                    element = self.item_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_id_list[i] = element.to_alipay_dict()
            if hasattr(self.item_id_list, 'to_alipay_dict'):
                params['item_id_list'] = self.item_id_list.to_alipay_dict()
            else:
                params['item_id_list'] = self.item_id_list
        if self.ocpx_switch:
            if hasattr(self.ocpx_switch, 'to_alipay_dict'):
                params['ocpx_switch'] = self.ocpx_switch.to_alipay_dict()
            else:
                params['ocpx_switch'] = self.ocpx_switch
        if self.plan_outer_id:
            if hasattr(self.plan_outer_id, 'to_alipay_dict'):
                params['plan_outer_id'] = self.plan_outer_id.to_alipay_dict()
            else:
                params['plan_outer_id'] = self.plan_outer_id
        if self.target_cpa:
            if hasattr(self.target_cpa, 'to_alipay_dict'):
                params['target_cpa'] = self.target_cpa.to_alipay_dict()
            else:
                params['target_cpa'] = self.target_cpa
        if self.targeting_list:
            if isinstance(self.targeting_list, list):
                for i in range(0, len(self.targeting_list)):
                    element = self.targeting_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.targeting_list[i] = element.to_alipay_dict()
            if hasattr(self.targeting_list, 'to_alipay_dict'):
                params['targeting_list'] = self.targeting_list.to_alipay_dict()
            else:
                params['targeting_list'] = self.targeting_list
        if self.time_option:
            if hasattr(self.time_option, 'to_alipay_dict'):
                params['time_option'] = self.time_option.to_alipay_dict()
            else:
                params['time_option'] = self.time_option
        if self.time_schema:
            if hasattr(self.time_schema, 'to_alipay_dict'):
                params['time_schema'] = self.time_schema.to_alipay_dict()
            else:
                params['time_schema'] = self.time_schema
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OuterGroup()
        if 'conversion_id_list' in d:
            o.conversion_id_list = d['conversion_id_list']
        if 'conversion_type' in d:
            o.conversion_type = d['conversion_type']
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'group_charge' in d:
            o.group_charge = d['group_charge']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'group_name' in d:
            o.group_name = d['group_name']
        if 'group_outer_id' in d:
            o.group_outer_id = d['group_outer_id']
        if 'group_status' in d:
            o.group_status = d['group_status']
        if 'item_id_list' in d:
            o.item_id_list = d['item_id_list']
        if 'ocpx_switch' in d:
            o.ocpx_switch = d['ocpx_switch']
        if 'plan_outer_id' in d:
            o.plan_outer_id = d['plan_outer_id']
        if 'target_cpa' in d:
            o.target_cpa = d['target_cpa']
        if 'targeting_list' in d:
            o.targeting_list = d['targeting_list']
        if 'time_option' in d:
            o.time_option = d['time_option']
        if 'time_schema' in d:
            o.time_schema = d['time_schema']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OuterGroup import OuterGroup


class AlipayDataDataserviceAdGroupQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataserviceAdGroupQueryResponse, self).__init__()
        self._group_detail = None

    @property
    def group_detail(self):
        return self._group_detail

    @group_detail.setter
    def group_detail(self, value):
        if isinstance(value, OuterGroup):
            self._group_detail = value
        else:
            self._group_detail = OuterGroup.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataserviceAdGroupQueryResponse, self).parse_response_content(response_content)
        if 'group_detail' in response:
            self.group_detail = response['group_detail']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FundExtInfo import FundExtInfo


class AlipayFundEnterprisepayMemberModifyModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._biz_scene = None
        self._fund_ext_info = None
        self._group_id_list = None
        self._open_id = None
        self._operation_type_list = None
        self._product_code = None
        self._user_id = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def fund_ext_info(self):
        return self._fund_ext_info

    @fund_ext_info.setter
    def fund_ext_info(self, value):
        if isinstance(value, FundExtInfo):
            self._fund_ext_info = value
        else:
            self._fund_ext_info = FundExtInfo.from_alipay_dict(value)
    @property
    def group_id_list(self):
        return self._group_id_list

    @group_id_list.setter
    def group_id_list(self, value):
        if isinstance(value, list):
            self._group_id_list = list()
            for i in value:
                self._group_id_list.append(i)
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def operation_type_list(self):
        return self._operation_type_list

    @operation_type_list.setter
    def operation_type_list(self, value):
        if isinstance(value, list):
            self._operation_type_list = list()
            for i in value:
                self._operation_type_list.append(i)
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.fund_ext_info:
            if hasattr(self.fund_ext_info, 'to_alipay_dict'):
                params['fund_ext_info'] = self.fund_ext_info.to_alipay_dict()
            else:
                params['fund_ext_info'] = self.fund_ext_info
        if self.group_id_list:
            if isinstance(self.group_id_list, list):
                for i in range(0, len(self.group_id_list)):
                    element = self.group_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.group_id_list[i] = element.to_alipay_dict()
            if hasattr(self.group_id_list, 'to_alipay_dict'):
                params['group_id_list'] = self.group_id_list.to_alipay_dict()
            else:
                params['group_id_list'] = self.group_id_list
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.operation_type_list:
            if isinstance(self.operation_type_list, list):
                for i in range(0, len(self.operation_type_list)):
                    element = self.operation_type_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.operation_type_list[i] = element.to_alipay_dict()
            if hasattr(self.operation_type_list, 'to_alipay_dict'):
                params['operation_type_list'] = self.operation_type_list.to_alipay_dict()
            else:
                params['operation_type_list'] = self.operation_type_list
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundEnterprisepayMemberModifyModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'fund_ext_info' in d:
            o.fund_ext_info = d['fund_ext_info']
        if 'group_id_list' in d:
            o.group_id_list = d['group_id_list']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'operation_type_list' in d:
            o.operation_type_list = d['operation_type_list']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ActivityGoods import ActivityGoods


class AlipayBossCommMsgtoCeBindModel(object):

    def __init__(self):
        self._business_scope = None
        self._cert_no = None
        self._hascode = None
        self._mobile = None
        self._province_code = None
        self._user_name = None

    @property
    def business_scope(self):
        return self._business_scope

    @business_scope.setter
    def business_scope(self, value):
        self._business_scope = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        if isinstance(value, ActivityGoods):
            self._cert_no = value
        else:
            self._cert_no = ActivityGoods.from_alipay_dict(value)
    @property
    def hascode(self):
        return self._hascode

    @hascode.setter
    def hascode(self, value):
        self._hascode = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        if isinstance(value, list):
            self._user_name = list()
            for i in value:
                self._user_name.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.business_scope:
            if hasattr(self.business_scope, 'to_alipay_dict'):
                params['business_scope'] = self.business_scope.to_alipay_dict()
            else:
                params['business_scope'] = self.business_scope
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.hascode:
            if hasattr(self.hascode, 'to_alipay_dict'):
                params['hascode'] = self.hascode.to_alipay_dict()
            else:
                params['hascode'] = self.hascode
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.user_name:
            if isinstance(self.user_name, list):
                for i in range(0, len(self.user_name)):
                    element = self.user_name[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.user_name[i] = element.to_alipay_dict()
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossCommMsgtoCeBindModel()
        if 'business_scope' in d:
            o.business_scope = d['business_scope']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'hascode' in d:
            o.hascode = d['hascode']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntfortuneYebAssetTradeUnfreezeModel(object):

    def __init__(self):
        self._amount = None
        self._freeze_code = None
        self._open_id = None
        self._out_biz_no = None
        self._user_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def freeze_code(self):
        return self._freeze_code

    @freeze_code.setter
    def freeze_code(self, value):
        self._freeze_code = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.freeze_code:
            if hasattr(self.freeze_code, 'to_alipay_dict'):
                params['freeze_code'] = self.freeze_code.to_alipay_dict()
            else:
                params['freeze_code'] = self.freeze_code
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntfortuneYebAssetTradeUnfreezeModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'freeze_code' in d:
            o.freeze_code = d['freeze_code']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ExtTemplateConf import ExtTemplateConf
from alipay.aop.api.domain.PreOrderExtInfo import PreOrderExtInfo


class ZhimaCreditPeZmgoPreorderCreateModel(object):

    def __init__(self):
        self._alipay_open_id = None
        self._alipay_user_id = None
        self._biz_time = None
        self._custom_temp_conf = None
        self._expire_aisle_data = None
        self._ext_template_conf = None
        self._extend_params = None
        self._freeze_amount = None
        self._isv_pid = None
        self._out_request_no = None
        self._partner_id = None
        self._partner_user_identifier = None
        self._pay_aisle_data = None
        self._sign_aisle_data = None
        self._template_id = None
        self._timeout_express = None

    @property
    def alipay_open_id(self):
        return self._alipay_open_id

    @alipay_open_id.setter
    def alipay_open_id(self, value):
        self._alipay_open_id = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def custom_temp_conf(self):
        return self._custom_temp_conf

    @custom_temp_conf.setter
    def custom_temp_conf(self, value):
        self._custom_temp_conf = value
    @property
    def expire_aisle_data(self):
        return self._expire_aisle_data

    @expire_aisle_data.setter
    def expire_aisle_data(self, value):
        self._expire_aisle_data = value
    @property
    def ext_template_conf(self):
        return self._ext_template_conf

    @ext_template_conf.setter
    def ext_template_conf(self, value):
        if isinstance(value, ExtTemplateConf):
            self._ext_template_conf = value
        else:
            self._ext_template_conf = ExtTemplateConf.from_alipay_dict(value)
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        if isinstance(value, PreOrderExtInfo):
            self._extend_params = value
        else:
            self._extend_params = PreOrderExtInfo.from_alipay_dict(value)
    @property
    def freeze_amount(self):
        return self._freeze_amount

    @freeze_amount.setter
    def freeze_amount(self, value):
        self._freeze_amount = value
    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def partner_user_identifier(self):
        return self._partner_user_identifier

    @partner_user_identifier.setter
    def partner_user_identifier(self, value):
        self._partner_user_identifier = value
    @property
    def pay_aisle_data(self):
        return self._pay_aisle_data

    @pay_aisle_data.setter
    def pay_aisle_data(self, value):
        self._pay_aisle_data = value
    @property
    def sign_aisle_data(self):
        return self._sign_aisle_data

    @sign_aisle_data.setter
    def sign_aisle_data(self, value):
        self._sign_aisle_data = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def timeout_express(self):
        return self._timeout_express

    @timeout_express.setter
    def timeout_express(self, value):
        self._timeout_express = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_open_id:
            if hasattr(self.alipay_open_id, 'to_alipay_dict'):
                params['alipay_open_id'] = self.alipay_open_id.to_alipay_dict()
            else:
                params['alipay_open_id'] = self.alipay_open_id
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.custom_temp_conf:
            if hasattr(self.custom_temp_conf, 'to_alipay_dict'):
                params['custom_temp_conf'] = self.custom_temp_conf.to_alipay_dict()
            else:
                params['custom_temp_conf'] = self.custom_temp_conf
        if self.expire_aisle_data:
            if hasattr(self.expire_aisle_data, 'to_alipay_dict'):
                params['expire_aisle_data'] = self.expire_aisle_data.to_alipay_dict()
            else:
                params['expire_aisle_data'] = self.expire_aisle_data
        if self.ext_template_conf:
            if hasattr(self.ext_template_conf, 'to_alipay_dict'):
                params['ext_template_conf'] = self.ext_template_conf.to_alipay_dict()
            else:
                params['ext_template_conf'] = self.ext_template_conf
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.freeze_amount:
            if hasattr(self.freeze_amount, 'to_alipay_dict'):
                params['freeze_amount'] = self.freeze_amount.to_alipay_dict()
            else:
                params['freeze_amount'] = self.freeze_amount
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.partner_user_identifier:
            if hasattr(self.partner_user_identifier, 'to_alipay_dict'):
                params['partner_user_identifier'] = self.partner_user_identifier.to_alipay_dict()
            else:
                params['partner_user_identifier'] = self.partner_user_identifier
        if self.pay_aisle_data:
            if hasattr(self.pay_aisle_data, 'to_alipay_dict'):
                params['pay_aisle_data'] = self.pay_aisle_data.to_alipay_dict()
            else:
                params['pay_aisle_data'] = self.pay_aisle_data
        if self.sign_aisle_data:
            if hasattr(self.sign_aisle_data, 'to_alipay_dict'):
                params['sign_aisle_data'] = self.sign_aisle_data.to_alipay_dict()
            else:
                params['sign_aisle_data'] = self.sign_aisle_data
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.timeout_express:
            if hasattr(self.timeout_express, 'to_alipay_dict'):
                params['timeout_express'] = self.timeout_express.to_alipay_dict()
            else:
                params['timeout_express'] = self.timeout_express
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPeZmgoPreorderCreateModel()
        if 'alipay_open_id' in d:
            o.alipay_open_id = d['alipay_open_id']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'custom_temp_conf' in d:
            o.custom_temp_conf = d['custom_temp_conf']
        if 'expire_aisle_data' in d:
            o.expire_aisle_data = d['expire_aisle_data']
        if 'ext_template_conf' in d:
            o.ext_template_conf = d['ext_template_conf']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'freeze_amount' in d:
            o.freeze_amount = d['freeze_amount']
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'partner_user_identifier' in d:
            o.partner_user_identifier = d['partner_user_identifier']
        if 'pay_aisle_data' in d:
            o.pay_aisle_data = d['pay_aisle_data']
        if 'sign_aisle_data' in d:
            o.sign_aisle_data = d['sign_aisle_data']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'timeout_express' in d:
            o.timeout_express = d['timeout_express']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundEnterprisepayUnsignResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundEnterprisepayUnsignResponse, self).__init__()
        self._unsign_token = None
        self._unsign_url = None

    @property
    def unsign_token(self):
        return self._unsign_token

    @unsign_token.setter
    def unsign_token(self, value):
        self._unsign_token = value
    @property
    def unsign_url(self):
        return self._unsign_url

    @unsign_url.setter
    def unsign_url(self, value):
        self._unsign_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundEnterprisepayUnsignResponse, self).parse_response_content(response_content)
        if 'unsign_token' in response:
            self.unsign_token = response['unsign_token']
        if 'unsign_url' in response:
            self.unsign_url = response['unsign_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SendVoucherInfoResult(object):

    def __init__(self):
        self._merchant_order_url = None
        self._voucher_code = None
        self._voucher_code_url = None

    @property
    def merchant_order_url(self):
        return self._merchant_order_url

    @merchant_order_url.setter
    def merchant_order_url(self, value):
        self._merchant_order_url = value
    @property
    def voucher_code(self):
        return self._voucher_code

    @voucher_code.setter
    def voucher_code(self, value):
        self._voucher_code = value
    @property
    def voucher_code_url(self):
        return self._voucher_code_url

    @voucher_code_url.setter
    def voucher_code_url(self, value):
        self._voucher_code_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.merchant_order_url:
            if hasattr(self.merchant_order_url, 'to_alipay_dict'):
                params['merchant_order_url'] = self.merchant_order_url.to_alipay_dict()
            else:
                params['merchant_order_url'] = self.merchant_order_url
        if self.voucher_code:
            if hasattr(self.voucher_code, 'to_alipay_dict'):
                params['voucher_code'] = self.voucher_code.to_alipay_dict()
            else:
                params['voucher_code'] = self.voucher_code
        if self.voucher_code_url:
            if hasattr(self.voucher_code_url, 'to_alipay_dict'):
                params['voucher_code_url'] = self.voucher_code_url.to_alipay_dict()
            else:
                params['voucher_code_url'] = self.voucher_code_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SendVoucherInfoResult()
        if 'merchant_order_url' in d:
            o.merchant_order_url = d['merchant_order_url']
        if 'voucher_code' in d:
            o.voucher_code = d['voucher_code']
        if 'voucher_code_url' in d:
            o.voucher_code_url = d['voucher_code_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CorpEntity import CorpEntity
from alipay.aop.api.domain.CorpEntity import CorpEntity
from alipay.aop.api.domain.NotaryFileVO import NotaryFileVO


class AlipayBossProdAntlegalchainMultipartyApplyModel(object):

    def __init__(self):
        self._apply_buc_user_no = None
        self._biz_code = None
        self._biz_name = None
        self._biz_unique_id = None
        self._corp_entity_multi_list = None
        self._init_corp_entity = None
        self._notary_file_list = None
        self._request_app_name = None
        self._request_time_stamp = None
        self._request_token = None
        self._sign_order_type = None
        self._submit_time = None

    @property
    def apply_buc_user_no(self):
        return self._apply_buc_user_no

    @apply_buc_user_no.setter
    def apply_buc_user_no(self, value):
        self._apply_buc_user_no = value
    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def biz_name(self):
        return self._biz_name

    @biz_name.setter
    def biz_name(self, value):
        self._biz_name = value
    @property
    def biz_unique_id(self):
        return self._biz_unique_id

    @biz_unique_id.setter
    def biz_unique_id(self, value):
        self._biz_unique_id = value
    @property
    def corp_entity_multi_list(self):
        return self._corp_entity_multi_list

    @corp_entity_multi_list.setter
    def corp_entity_multi_list(self, value):
        if isinstance(value, list):
            self._corp_entity_multi_list = list()
            for i in value:
                if isinstance(i, CorpEntity):
                    self._corp_entity_multi_list.append(i)
                else:
                    self._corp_entity_multi_list.append(CorpEntity.from_alipay_dict(i))
    @property
    def init_corp_entity(self):
        return self._init_corp_entity

    @init_corp_entity.setter
    def init_corp_entity(self, value):
        if isinstance(value, CorpEntity):
            self._init_corp_entity = value
        else:
            self._init_corp_entity = CorpEntity.from_alipay_dict(value)
    @property
    def notary_file_list(self):
        return self._notary_file_list

    @notary_file_list.setter
    def notary_file_list(self, value):
        if isinstance(value, list):
            self._notary_file_list = list()
            for i in value:
                if isinstance(i, NotaryFileVO):
                    self._notary_file_list.append(i)
                else:
                    self._notary_file_list.append(NotaryFileVO.from_alipay_dict(i))
    @property
    def request_app_name(self):
        return self._request_app_name

    @request_app_name.setter
    def request_app_name(self, value):
        self._request_app_name = value
    @property
    def request_time_stamp(self):
        return self._request_time_stamp

    @request_time_stamp.setter
    def request_time_stamp(self, value):
        self._request_time_stamp = value
    @property
    def request_token(self):
        return self._request_token

    @request_token.setter
    def request_token(self, value):
        self._request_token = value
    @property
    def sign_order_type(self):
        return self._sign_order_type

    @sign_order_type.setter
    def sign_order_type(self, value):
        self._sign_order_type = value
    @property
    def submit_time(self):
        return self._submit_time

    @submit_time.setter
    def submit_time(self, value):
        self._submit_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_buc_user_no:
            if hasattr(self.apply_buc_user_no, 'to_alipay_dict'):
                params['apply_buc_user_no'] = self.apply_buc_user_no.to_alipay_dict()
            else:
                params['apply_buc_user_no'] = self.apply_buc_user_no
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.biz_name:
            if hasattr(self.biz_name, 'to_alipay_dict'):
                params['biz_name'] = self.biz_name.to_alipay_dict()
            else:
                params['biz_name'] = self.biz_name
        if self.biz_unique_id:
            if hasattr(self.biz_unique_id, 'to_alipay_dict'):
                params['biz_unique_id'] = self.biz_unique_id.to_alipay_dict()
            else:
                params['biz_unique_id'] = self.biz_unique_id
        if self.corp_entity_multi_list:
            if isinstance(self.corp_entity_multi_list, list):
                for i in range(0, len(self.corp_entity_multi_list)):
                    element = self.corp_entity_multi_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.corp_entity_multi_list[i] = element.to_alipay_dict()
            if hasattr(self.corp_entity_multi_list, 'to_alipay_dict'):
                params['corp_entity_multi_list'] = self.corp_entity_multi_list.to_alipay_dict()
            else:
                params['corp_entity_multi_list'] = self.corp_entity_multi_list
        if self.init_corp_entity:
            if hasattr(self.init_corp_entity, 'to_alipay_dict'):
                params['init_corp_entity'] = self.init_corp_entity.to_alipay_dict()
            else:
                params['init_corp_entity'] = self.init_corp_entity
        if self.notary_file_list:
            if isinstance(self.notary_file_list, list):
                for i in range(0, len(self.notary_file_list)):
                    element = self.notary_file_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.notary_file_list[i] = element.to_alipay_dict()
            if hasattr(self.notary_file_list, 'to_alipay_dict'):
                params['notary_file_list'] = self.notary_file_list.to_alipay_dict()
            else:
                params['notary_file_list'] = self.notary_file_list
        if self.request_app_name:
            if hasattr(self.request_app_name, 'to_alipay_dict'):
                params['request_app_name'] = self.request_app_name.to_alipay_dict()
            else:
                params['request_app_name'] = self.request_app_name
        if self.request_time_stamp:
            if hasattr(self.request_time_stamp, 'to_alipay_dict'):
                params['request_time_stamp'] = self.request_time_stamp.to_alipay_dict()
            else:
                params['request_time_stamp'] = self.request_time_stamp
        if self.request_token:
            if hasattr(self.request_token, 'to_alipay_dict'):
                params['request_token'] = self.request_token.to_alipay_dict()
            else:
                params['request_token'] = self.request_token
        if self.sign_order_type:
            if hasattr(self.sign_order_type, 'to_alipay_dict'):
                params['sign_order_type'] = self.sign_order_type.to_alipay_dict()
            else:
                params['sign_order_type'] = self.sign_order_type
        if self.submit_time:
            if hasattr(self.submit_time, 'to_alipay_dict'):
                params['submit_time'] = self.submit_time.to_alipay_dict()
            else:
                params['submit_time'] = self.submit_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossProdAntlegalchainMultipartyApplyModel()
        if 'apply_buc_user_no' in d:
            o.apply_buc_user_no = d['apply_buc_user_no']
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'biz_name' in d:
            o.biz_name = d['biz_name']
        if 'biz_unique_id' in d:
            o.biz_unique_id = d['biz_unique_id']
        if 'corp_entity_multi_list' in d:
            o.corp_entity_multi_list = d['corp_entity_multi_list']
        if 'init_corp_entity' in d:
            o.init_corp_entity = d['init_corp_entity']
        if 'notary_file_list' in d:
            o.notary_file_list = d['notary_file_list']
        if 'request_app_name' in d:
            o.request_app_name = d['request_app_name']
        if 'request_time_stamp' in d:
            o.request_time_stamp = d['request_time_stamp']
        if 'request_token' in d:
            o.request_token = d['request_token']
        if 'sign_order_type' in d:
            o.sign_order_type = d['sign_order_type']
        if 'submit_time' in d:
            o.submit_time = d['submit_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditPeZmgoCumulationSyncResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditPeZmgoCumulationSyncResponse, self).__init__()
        self._agreement_no = None
        self._fail_reason = None
        self._open_id = None
        self._out_biz_no = None
        self._user_id = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def fail_reason(self):
        return self._fail_reason

    @fail_reason.setter
    def fail_reason(self, value):
        self._fail_reason = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditPeZmgoCumulationSyncResponse, self).parse_response_content(response_content)
        if 'agreement_no' in response:
            self.agreement_no = response['agreement_no']
        if 'fail_reason' in response:
            self.fail_reason = response['fail_reason']
        if 'open_id' in response:
            self.open_id = response['open_id']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataServiceResult(object):

    def __init__(self):
        self._code = None
        self._message = None
        self._result = None
        self._success = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value
    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.message:
            if hasattr(self.message, 'to_alipay_dict'):
                params['message'] = self.message.to_alipay_dict()
            else:
                params['message'] = self.message
        if self.result:
            if hasattr(self.result, 'to_alipay_dict'):
                params['result'] = self.result.to_alipay_dict()
            else:
                params['result'] = self.result
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataServiceResult()
        if 'code' in d:
            o.code = d['code']
        if 'message' in d:
            o.message = d['message']
        if 'result' in d:
            o.result = d['result']
        if 'success' in d:
            o.success = d['success']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiShopMantestsdsSendModel(object):

    def __init__(self):
        self._opopo = None

    @property
    def opopo(self):
        return self._opopo

    @opopo.setter
    def opopo(self, value):
        self._opopo = value


    def to_alipay_dict(self):
        params = dict()
        if self.opopo:
            if hasattr(self.opopo, 'to_alipay_dict'):
                params['opopo'] = self.opopo.to_alipay_dict()
            else:
                params['opopo'] = self.opopo
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiShopMantestsdsSendModel()
        if 'opopo' in d:
            o.opopo = d['opopo']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AlCollectionCreateDebtDTO import AlCollectionCreateDebtDTO
from alipay.aop.api.domain.AlCollectionReceiveBaseInfoDTO import AlCollectionReceiveBaseInfoDTO
from alipay.aop.api.domain.ContractInfoDTO import ContractInfoDTO
from alipay.aop.api.domain.OppositeSubjectDTO import OppositeSubjectDTO
from alipay.aop.api.domain.OurSubjectInfoDTO import OurSubjectInfoDTO


class AntLinkeAlcollectioncenterCreateModel(object):

    def __init__(self):
        self._al_collection_create_debt = None
        self._app_name = None
        self._base_info = None
        self._contract_info = None
        self._operator = None
        self._opposite_subject_dto = None
        self._our_subject_info = None
        self._tenant = None

    @property
    def al_collection_create_debt(self):
        return self._al_collection_create_debt

    @al_collection_create_debt.setter
    def al_collection_create_debt(self, value):
        if isinstance(value, AlCollectionCreateDebtDTO):
            self._al_collection_create_debt = value
        else:
            self._al_collection_create_debt = AlCollectionCreateDebtDTO.from_alipay_dict(value)
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def base_info(self):
        return self._base_info

    @base_info.setter
    def base_info(self, value):
        if isinstance(value, AlCollectionReceiveBaseInfoDTO):
            self._base_info = value
        else:
            self._base_info = AlCollectionReceiveBaseInfoDTO.from_alipay_dict(value)
    @property
    def contract_info(self):
        return self._contract_info

    @contract_info.setter
    def contract_info(self, value):
        if isinstance(value, ContractInfoDTO):
            self._contract_info = value
        else:
            self._contract_info = ContractInfoDTO.from_alipay_dict(value)
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def opposite_subject_dto(self):
        return self._opposite_subject_dto

    @opposite_subject_dto.setter
    def opposite_subject_dto(self, value):
        if isinstance(value, OppositeSubjectDTO):
            self._opposite_subject_dto = value
        else:
            self._opposite_subject_dto = OppositeSubjectDTO.from_alipay_dict(value)
    @property
    def our_subject_info(self):
        return self._our_subject_info

    @our_subject_info.setter
    def our_subject_info(self, value):
        if isinstance(value, OurSubjectInfoDTO):
            self._our_subject_info = value
        else:
            self._our_subject_info = OurSubjectInfoDTO.from_alipay_dict(value)
    @property
    def tenant(self):
        return self._tenant

    @tenant.setter
    def tenant(self, value):
        self._tenant = value


    def to_alipay_dict(self):
        params = dict()
        if self.al_collection_create_debt:
            if hasattr(self.al_collection_create_debt, 'to_alipay_dict'):
                params['al_collection_create_debt'] = self.al_collection_create_debt.to_alipay_dict()
            else:
                params['al_collection_create_debt'] = self.al_collection_create_debt
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.base_info:
            if hasattr(self.base_info, 'to_alipay_dict'):
                params['base_info'] = self.base_info.to_alipay_dict()
            else:
                params['base_info'] = self.base_info
        if self.contract_info:
            if hasattr(self.contract_info, 'to_alipay_dict'):
                params['contract_info'] = self.contract_info.to_alipay_dict()
            else:
                params['contract_info'] = self.contract_info
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.opposite_subject_dto:
            if hasattr(self.opposite_subject_dto, 'to_alipay_dict'):
                params['opposite_subject_dto'] = self.opposite_subject_dto.to_alipay_dict()
            else:
                params['opposite_subject_dto'] = self.opposite_subject_dto
        if self.our_subject_info:
            if hasattr(self.our_subject_info, 'to_alipay_dict'):
                params['our_subject_info'] = self.our_subject_info.to_alipay_dict()
            else:
                params['our_subject_info'] = self.our_subject_info
        if self.tenant:
            if hasattr(self.tenant, 'to_alipay_dict'):
                params['tenant'] = self.tenant.to_alipay_dict()
            else:
                params['tenant'] = self.tenant
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntLinkeAlcollectioncenterCreateModel()
        if 'al_collection_create_debt' in d:
            o.al_collection_create_debt = d['al_collection_create_debt']
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'base_info' in d:
            o.base_info = d['base_info']
        if 'contract_info' in d:
            o.contract_info = d['contract_info']
        if 'operator' in d:
            o.operator = d['operator']
        if 'opposite_subject_dto' in d:
            o.opposite_subject_dto = d['opposite_subject_dto']
        if 'our_subject_info' in d:
            o.our_subject_info = d['our_subject_info']
        if 'tenant' in d:
            o.tenant = d['tenant']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BkdfmacBizActionLogDTO import BkdfmacBizActionLogDTO


class MybankFinancialplatformBudgetReturnResponse(AlipayResponse):

    def __init__(self):
        super(MybankFinancialplatformBudgetReturnResponse, self).__init__()
        self._result_data = None
        self._result_msg = None

    @property
    def result_data(self):
        return self._result_data

    @result_data.setter
    def result_data(self, value):
        if isinstance(value, BkdfmacBizActionLogDTO):
            self._result_data = value
        else:
            self._result_data = BkdfmacBizActionLogDTO.from_alipay_dict(value)
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value

    def parse_response_content(self, response_content):
        response = super(MybankFinancialplatformBudgetReturnResponse, self).parse_response_content(response_content)
        if 'result_data' in response:
            self.result_data = response['result_data']
        if 'result_msg' in response:
            self.result_msg = response['result_msg']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CropsGrowthInfo import CropsGrowthInfo
from alipay.aop.api.domain.CropsHarvestForecastInfo import CropsHarvestForecastInfo
from alipay.aop.api.domain.CropsHarvestProgressInfo import CropsHarvestProgressInfo
from alipay.aop.api.domain.CropsPlantingInfo import CropsPlantingInfo
from alipay.aop.api.domain.CropsSoilMoistureInfo import CropsSoilMoistureInfo
from alipay.aop.api.domain.AgWeatherDisasterInfo import AgWeatherDisasterInfo
from alipay.aop.api.domain.AgWeatherForecastInfo import AgWeatherForecastInfo
from alipay.aop.api.domain.CropsYieldForecastInfo import CropsYieldForecastInfo


class AnttechBlockchainDefinDataserviceCropbaseQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinDataserviceCropbaseQueryResponse, self).__init__()
        self._crops = None
        self._growth_info = None
        self._harvest_forecast_info = None
        self._harvest_progress_info = None
        self._planting_info = None
        self._plot_area = None
        self._region_code = None
        self._soil_moisture_info = None
        self._update_date = None
        self._weather_disaster_info = None
        self._weather_forecast_info = None
        self._yield_forecast_info = None

    @property
    def crops(self):
        return self._crops

    @crops.setter
    def crops(self, value):
        if isinstance(value, list):
            self._crops = list()
            for i in value:
                self._crops.append(i)
    @property
    def growth_info(self):
        return self._growth_info

    @growth_info.setter
    def growth_info(self, value):
        if isinstance(value, list):
            self._growth_info = list()
            for i in value:
                if isinstance(i, CropsGrowthInfo):
                    self._growth_info.append(i)
                else:
                    self._growth_info.append(CropsGrowthInfo.from_alipay_dict(i))
    @property
    def harvest_forecast_info(self):
        return self._harvest_forecast_info

    @harvest_forecast_info.setter
    def harvest_forecast_info(self, value):
        if isinstance(value, list):
            self._harvest_forecast_info = list()
            for i in value:
                if isinstance(i, CropsHarvestForecastInfo):
                    self._harvest_forecast_info.append(i)
                else:
                    self._harvest_forecast_info.append(CropsHarvestForecastInfo.from_alipay_dict(i))
    @property
    def harvest_progress_info(self):
        return self._harvest_progress_info

    @harvest_progress_info.setter
    def harvest_progress_info(self, value):
        if isinstance(value, list):
            self._harvest_progress_info = list()
            for i in value:
                if isinstance(i, CropsHarvestProgressInfo):
                    self._harvest_progress_info.append(i)
                else:
                    self._harvest_progress_info.append(CropsHarvestProgressInfo.from_alipay_dict(i))
    @property
    def planting_info(self):
        return self._planting_info

    @planting_info.setter
    def planting_info(self, value):
        if isinstance(value, list):
            self._planting_info = list()
            for i in value:
                if isinstance(i, CropsPlantingInfo):
                    self._planting_info.append(i)
                else:
                    self._planting_info.append(CropsPlantingInfo.from_alipay_dict(i))
    @property
    def plot_area(self):
        return self._plot_area

    @plot_area.setter
    def plot_area(self, value):
        self._plot_area = value
    @property
    def region_code(self):
        return self._region_code

    @region_code.setter
    def region_code(self, value):
        self._region_code = value
    @property
    def soil_moisture_info(self):
        return self._soil_moisture_info

    @soil_moisture_info.setter
    def soil_moisture_info(self, value):
        if isinstance(value, list):
            self._soil_moisture_info = list()
            for i in value:
                if isinstance(i, CropsSoilMoistureInfo):
                    self._soil_moisture_info.append(i)
                else:
                    self._soil_moisture_info.append(CropsSoilMoistureInfo.from_alipay_dict(i))
    @property
    def update_date(self):
        return self._update_date

    @update_date.setter
    def update_date(self, value):
        self._update_date = value
    @property
    def weather_disaster_info(self):
        return self._weather_disaster_info

    @weather_disaster_info.setter
    def weather_disaster_info(self, value):
        if isinstance(value, AgWeatherDisasterInfo):
            self._weather_disaster_info = value
        else:
            self._weather_disaster_info = AgWeatherDisasterInfo.from_alipay_dict(value)
    @property
    def weather_forecast_info(self):
        return self._weather_forecast_info

    @weather_forecast_info.setter
    def weather_forecast_info(self, value):
        if isinstance(value, AgWeatherForecastInfo):
            self._weather_forecast_info = value
        else:
            self._weather_forecast_info = AgWeatherForecastInfo.from_alipay_dict(value)
    @property
    def yield_forecast_info(self):
        return self._yield_forecast_info

    @yield_forecast_info.setter
    def yield_forecast_info(self, value):
        if isinstance(value, list):
            self._yield_forecast_info = list()
            for i in value:
                if isinstance(i, CropsYieldForecastInfo):
                    self._yield_forecast_info.append(i)
                else:
                    self._yield_forecast_info.append(CropsYieldForecastInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinDataserviceCropbaseQueryResponse, self).parse_response_content(response_content)
        if 'crops' in response:
            self.crops = response['crops']
        if 'growth_info' in response:
            self.growth_info = response['growth_info']
        if 'harvest_forecast_info' in response:
            self.harvest_forecast_info = response['harvest_forecast_info']
        if 'harvest_progress_info' in response:
            self.harvest_progress_info = response['harvest_progress_info']
        if 'planting_info' in response:
            self.planting_info = response['planting_info']
        if 'plot_area' in response:
            self.plot_area = response['plot_area']
        if 'region_code' in response:
            self.region_code = response['region_code']
        if 'soil_moisture_info' in response:
            self.soil_moisture_info = response['soil_moisture_info']
        if 'update_date' in response:
            self.update_date = response['update_date']
        if 'weather_disaster_info' in response:
            self.weather_disaster_info = response['weather_disaster_info']
        if 'weather_forecast_info' in response:
            self.weather_forecast_info = response['weather_forecast_info']
        if 'yield_forecast_info' in response:
            self.yield_forecast_info = response['yield_forecast_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UpdatedAuthenticationDetails(object):

    def __init__(self):
        self._authentication_mechanisms = None
        self._nonce = None
        self._partial_transaction_details_signature = None
        self._pin_format = None
        self._signing_key_material = None

    @property
    def authentication_mechanisms(self):
        return self._authentication_mechanisms

    @authentication_mechanisms.setter
    def authentication_mechanisms(self, value):
        if isinstance(value, list):
            self._authentication_mechanisms = list()
            for i in value:
                self._authentication_mechanisms.append(i)
    @property
    def nonce(self):
        return self._nonce

    @nonce.setter
    def nonce(self, value):
        self._nonce = value
    @property
    def partial_transaction_details_signature(self):
        return self._partial_transaction_details_signature

    @partial_transaction_details_signature.setter
    def partial_transaction_details_signature(self, value):
        self._partial_transaction_details_signature = value
    @property
    def pin_format(self):
        return self._pin_format

    @pin_format.setter
    def pin_format(self, value):
        self._pin_format = value
    @property
    def signing_key_material(self):
        return self._signing_key_material

    @signing_key_material.setter
    def signing_key_material(self, value):
        self._signing_key_material = value


    def to_alipay_dict(self):
        params = dict()
        if self.authentication_mechanisms:
            if isinstance(self.authentication_mechanisms, list):
                for i in range(0, len(self.authentication_mechanisms)):
                    element = self.authentication_mechanisms[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.authentication_mechanisms[i] = element.to_alipay_dict()
            if hasattr(self.authentication_mechanisms, 'to_alipay_dict'):
                params['authentication_mechanisms'] = self.authentication_mechanisms.to_alipay_dict()
            else:
                params['authentication_mechanisms'] = self.authentication_mechanisms
        if self.nonce:
            if hasattr(self.nonce, 'to_alipay_dict'):
                params['nonce'] = self.nonce.to_alipay_dict()
            else:
                params['nonce'] = self.nonce
        if self.partial_transaction_details_signature:
            if hasattr(self.partial_transaction_details_signature, 'to_alipay_dict'):
                params['partial_transaction_details_signature'] = self.partial_transaction_details_signature.to_alipay_dict()
            else:
                params['partial_transaction_details_signature'] = self.partial_transaction_details_signature
        if self.pin_format:
            if hasattr(self.pin_format, 'to_alipay_dict'):
                params['pin_format'] = self.pin_format.to_alipay_dict()
            else:
                params['pin_format'] = self.pin_format
        if self.signing_key_material:
            if hasattr(self.signing_key_material, 'to_alipay_dict'):
                params['signing_key_material'] = self.signing_key_material.to_alipay_dict()
            else:
                params['signing_key_material'] = self.signing_key_material
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UpdatedAuthenticationDetails()
        if 'authentication_mechanisms' in d:
            o.authentication_mechanisms = d['authentication_mechanisms']
        if 'nonce' in d:
            o.nonce = d['nonce']
        if 'partial_transaction_details_signature' in d:
            o.partial_transaction_details_signature = d['partial_transaction_details_signature']
        if 'pin_format' in d:
            o.pin_format = d['pin_format']
        if 'signing_key_material' in d:
            o.signing_key_material = d['signing_key_material']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ActivityDiscountVoucher(object):

    def __init__(self):
        self._ceiling_amount = None
        self._discount = None
        self._floor_amount = None
        self._goods_name = None
        self._origin_amount = None

    @property
    def ceiling_amount(self):
        return self._ceiling_amount

    @ceiling_amount.setter
    def ceiling_amount(self, value):
        self._ceiling_amount = value
    @property
    def discount(self):
        return self._discount

    @discount.setter
    def discount(self, value):
        self._discount = value
    @property
    def floor_amount(self):
        return self._floor_amount

    @floor_amount.setter
    def floor_amount(self, value):
        self._floor_amount = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def origin_amount(self):
        return self._origin_amount

    @origin_amount.setter
    def origin_amount(self, value):
        self._origin_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.ceiling_amount:
            if hasattr(self.ceiling_amount, 'to_alipay_dict'):
                params['ceiling_amount'] = self.ceiling_amount.to_alipay_dict()
            else:
                params['ceiling_amount'] = self.ceiling_amount
        if self.discount:
            if hasattr(self.discount, 'to_alipay_dict'):
                params['discount'] = self.discount.to_alipay_dict()
            else:
                params['discount'] = self.discount
        if self.floor_amount:
            if hasattr(self.floor_amount, 'to_alipay_dict'):
                params['floor_amount'] = self.floor_amount.to_alipay_dict()
            else:
                params['floor_amount'] = self.floor_amount
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.origin_amount:
            if hasattr(self.origin_amount, 'to_alipay_dict'):
                params['origin_amount'] = self.origin_amount.to_alipay_dict()
            else:
                params['origin_amount'] = self.origin_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityDiscountVoucher()
        if 'ceiling_amount' in d:
            o.ceiling_amount = d['ceiling_amount']
        if 'discount' in d:
            o.discount = d['discount']
        if 'floor_amount' in d:
            o.floor_amount = d['floor_amount']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'origin_amount' in d:
            o.origin_amount = d['origin_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppTestGraySendModel(object):

    def __init__(self):
        self._oid = None

    @property
    def oid(self):
        return self._oid

    @oid.setter
    def oid(self, value):
        self._oid = value


    def to_alipay_dict(self):
        params = dict()
        if self.oid:
            if hasattr(self.oid, 'to_alipay_dict'):
                params['oid'] = self.oid.to_alipay_dict()
            else:
                params['oid'] = self.oid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppTestGraySendModel()
        if 'oid' in d:
            o.oid = d['oid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IotDeviceModel(object):

    def __init__(self):
        self._category_id = None
        self._connection_types = None
        self._connection_url = None
        self._decription = None
        self._icon = None
        self._manufacturer = None
        self._model_id = None
        self._model_name = None

    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def connection_types(self):
        return self._connection_types

    @connection_types.setter
    def connection_types(self, value):
        if isinstance(value, list):
            self._connection_types = list()
            for i in value:
                self._connection_types.append(i)
    @property
    def connection_url(self):
        return self._connection_url

    @connection_url.setter
    def connection_url(self, value):
        self._connection_url = value
    @property
    def decription(self):
        return self._decription

    @decription.setter
    def decription(self, value):
        self._decription = value
    @property
    def icon(self):
        return self._icon

    @icon.setter
    def icon(self, value):
        self._icon = value
    @property
    def manufacturer(self):
        return self._manufacturer

    @manufacturer.setter
    def manufacturer(self, value):
        self._manufacturer = value
    @property
    def model_id(self):
        return self._model_id

    @model_id.setter
    def model_id(self, value):
        self._model_id = value
    @property
    def model_name(self):
        return self._model_name

    @model_name.setter
    def model_name(self, value):
        self._model_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.connection_types:
            if isinstance(self.connection_types, list):
                for i in range(0, len(self.connection_types)):
                    element = self.connection_types[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.connection_types[i] = element.to_alipay_dict()
            if hasattr(self.connection_types, 'to_alipay_dict'):
                params['connection_types'] = self.connection_types.to_alipay_dict()
            else:
                params['connection_types'] = self.connection_types
        if self.connection_url:
            if hasattr(self.connection_url, 'to_alipay_dict'):
                params['connection_url'] = self.connection_url.to_alipay_dict()
            else:
                params['connection_url'] = self.connection_url
        if self.decription:
            if hasattr(self.decription, 'to_alipay_dict'):
                params['decription'] = self.decription.to_alipay_dict()
            else:
                params['decription'] = self.decription
        if self.icon:
            if hasattr(self.icon, 'to_alipay_dict'):
                params['icon'] = self.icon.to_alipay_dict()
            else:
                params['icon'] = self.icon
        if self.manufacturer:
            if hasattr(self.manufacturer, 'to_alipay_dict'):
                params['manufacturer'] = self.manufacturer.to_alipay_dict()
            else:
                params['manufacturer'] = self.manufacturer
        if self.model_id:
            if hasattr(self.model_id, 'to_alipay_dict'):
                params['model_id'] = self.model_id.to_alipay_dict()
            else:
                params['model_id'] = self.model_id
        if self.model_name:
            if hasattr(self.model_name, 'to_alipay_dict'):
                params['model_name'] = self.model_name.to_alipay_dict()
            else:
                params['model_name'] = self.model_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IotDeviceModel()
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'connection_types' in d:
            o.connection_types = d['connection_types']
        if 'connection_url' in d:
            o.connection_url = d['connection_url']
        if 'decription' in d:
            o.decription = d['decription']
        if 'icon' in d:
            o.icon = d['icon']
        if 'manufacturer' in d:
            o.manufacturer = d['manufacturer']
        if 'model_id' in d:
            o.model_id = d['model_id']
        if 'model_name' in d:
            o.model_name = d['model_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CropsHarvestForecastInfo(object):

    def __init__(self):
        self._actual_date = None
        self._addition_info = None
        self._create_date = None
        self._crop_code = None
        self._estimate_harvest_time = None
        self._is_harvest_time = None
        self._maturity = None

    @property
    def actual_date(self):
        return self._actual_date

    @actual_date.setter
    def actual_date(self, value):
        self._actual_date = value
    @property
    def addition_info(self):
        return self._addition_info

    @addition_info.setter
    def addition_info(self, value):
        self._addition_info = value
    @property
    def create_date(self):
        return self._create_date

    @create_date.setter
    def create_date(self, value):
        self._create_date = value
    @property
    def crop_code(self):
        return self._crop_code

    @crop_code.setter
    def crop_code(self, value):
        self._crop_code = value
    @property
    def estimate_harvest_time(self):
        return self._estimate_harvest_time

    @estimate_harvest_time.setter
    def estimate_harvest_time(self, value):
        self._estimate_harvest_time = value
    @property
    def is_harvest_time(self):
        return self._is_harvest_time

    @is_harvest_time.setter
    def is_harvest_time(self, value):
        self._is_harvest_time = value
    @property
    def maturity(self):
        return self._maturity

    @maturity.setter
    def maturity(self, value):
        self._maturity = value


    def to_alipay_dict(self):
        params = dict()
        if self.actual_date:
            if hasattr(self.actual_date, 'to_alipay_dict'):
                params['actual_date'] = self.actual_date.to_alipay_dict()
            else:
                params['actual_date'] = self.actual_date
        if self.addition_info:
            if hasattr(self.addition_info, 'to_alipay_dict'):
                params['addition_info'] = self.addition_info.to_alipay_dict()
            else:
                params['addition_info'] = self.addition_info
        if self.create_date:
            if hasattr(self.create_date, 'to_alipay_dict'):
                params['create_date'] = self.create_date.to_alipay_dict()
            else:
                params['create_date'] = self.create_date
        if self.crop_code:
            if hasattr(self.crop_code, 'to_alipay_dict'):
                params['crop_code'] = self.crop_code.to_alipay_dict()
            else:
                params['crop_code'] = self.crop_code
        if self.estimate_harvest_time:
            if hasattr(self.estimate_harvest_time, 'to_alipay_dict'):
                params['estimate_harvest_time'] = self.estimate_harvest_time.to_alipay_dict()
            else:
                params['estimate_harvest_time'] = self.estimate_harvest_time
        if self.is_harvest_time:
            if hasattr(self.is_harvest_time, 'to_alipay_dict'):
                params['is_harvest_time'] = self.is_harvest_time.to_alipay_dict()
            else:
                params['is_harvest_time'] = self.is_harvest_time
        if self.maturity:
            if hasattr(self.maturity, 'to_alipay_dict'):
                params['maturity'] = self.maturity.to_alipay_dict()
            else:
                params['maturity'] = self.maturity
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CropsHarvestForecastInfo()
        if 'actual_date' in d:
            o.actual_date = d['actual_date']
        if 'addition_info' in d:
            o.addition_info = d['addition_info']
        if 'create_date' in d:
            o.create_date = d['create_date']
        if 'crop_code' in d:
            o.crop_code = d['crop_code']
        if 'estimate_harvest_time' in d:
            o.estimate_harvest_time = d['estimate_harvest_time']
        if 'is_harvest_time' in d:
            o.is_harvest_time = d['is_harvest_time']
        if 'maturity' in d:
            o.maturity = d['maturity']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditPeZmgoPreConsultModel(object):

    def __init__(self):
        self._alipay_user_id = None
        self._open_id = None
        self._partner_id = None
        self._phone = None
        self._query_level = None
        self._template_id = None

    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value
    @property
    def query_level(self):
        return self._query_level

    @query_level.setter
    def query_level(self, value):
        self._query_level = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.query_level:
            if hasattr(self.query_level, 'to_alipay_dict'):
                params['query_level'] = self.query_level.to_alipay_dict()
            else:
                params['query_level'] = self.query_level
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPeZmgoPreConsultModel()
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'phone' in d:
            o.phone = d['phone']
        if 'query_level' in d:
            o.query_level = d['query_level']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class QueryAppInfoExt(object):

    def __init__(self):
        self._app_name = None
        self._app_number = None
        self._application_type = None
        self._callback_url = None
        self._charset_type = None
        self._dev_id = None
        self._gateway_url = None
        self._package_code_set = None
        self._pid = None
        self._signature_type = None
        self._status = None
        self._use_encrypt = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_number(self):
        return self._app_number

    @app_number.setter
    def app_number(self, value):
        self._app_number = value
    @property
    def application_type(self):
        return self._application_type

    @application_type.setter
    def application_type(self, value):
        self._application_type = value
    @property
    def callback_url(self):
        return self._callback_url

    @callback_url.setter
    def callback_url(self, value):
        self._callback_url = value
    @property
    def charset_type(self):
        return self._charset_type

    @charset_type.setter
    def charset_type(self, value):
        self._charset_type = value
    @property
    def dev_id(self):
        return self._dev_id

    @dev_id.setter
    def dev_id(self, value):
        self._dev_id = value
    @property
    def gateway_url(self):
        return self._gateway_url

    @gateway_url.setter
    def gateway_url(self, value):
        self._gateway_url = value
    @property
    def package_code_set(self):
        return self._package_code_set

    @package_code_set.setter
    def package_code_set(self, value):
        if isinstance(value, list):
            self._package_code_set = list()
            for i in value:
                self._package_code_set.append(i)
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value
    @property
    def signature_type(self):
        return self._signature_type

    @signature_type.setter
    def signature_type(self, value):
        self._signature_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def use_encrypt(self):
        return self._use_encrypt

    @use_encrypt.setter
    def use_encrypt(self, value):
        self._use_encrypt = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.app_number:
            if hasattr(self.app_number, 'to_alipay_dict'):
                params['app_number'] = self.app_number.to_alipay_dict()
            else:
                params['app_number'] = self.app_number
        if self.application_type:
            if hasattr(self.application_type, 'to_alipay_dict'):
                params['application_type'] = self.application_type.to_alipay_dict()
            else:
                params['application_type'] = self.application_type
        if self.callback_url:
            if hasattr(self.callback_url, 'to_alipay_dict'):
                params['callback_url'] = self.callback_url.to_alipay_dict()
            else:
                params['callback_url'] = self.callback_url
        if self.charset_type:
            if hasattr(self.charset_type, 'to_alipay_dict'):
                params['charset_type'] = self.charset_type.to_alipay_dict()
            else:
                params['charset_type'] = self.charset_type
        if self.dev_id:
            if hasattr(self.dev_id, 'to_alipay_dict'):
                params['dev_id'] = self.dev_id.to_alipay_dict()
            else:
                params['dev_id'] = self.dev_id
        if self.gateway_url:
            if hasattr(self.gateway_url, 'to_alipay_dict'):
                params['gateway_url'] = self.gateway_url.to_alipay_dict()
            else:
                params['gateway_url'] = self.gateway_url
        if self.package_code_set:
            if isinstance(self.package_code_set, list):
                for i in range(0, len(self.package_code_set)):
                    element = self.package_code_set[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.package_code_set[i] = element.to_alipay_dict()
            if hasattr(self.package_code_set, 'to_alipay_dict'):
                params['package_code_set'] = self.package_code_set.to_alipay_dict()
            else:
                params['package_code_set'] = self.package_code_set
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        if self.signature_type:
            if hasattr(self.signature_type, 'to_alipay_dict'):
                params['signature_type'] = self.signature_type.to_alipay_dict()
            else:
                params['signature_type'] = self.signature_type
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.use_encrypt:
            if hasattr(self.use_encrypt, 'to_alipay_dict'):
                params['use_encrypt'] = self.use_encrypt.to_alipay_dict()
            else:
                params['use_encrypt'] = self.use_encrypt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QueryAppInfoExt()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'app_number' in d:
            o.app_number = d['app_number']
        if 'application_type' in d:
            o.application_type = d['application_type']
        if 'callback_url' in d:
            o.callback_url = d['callback_url']
        if 'charset_type' in d:
            o.charset_type = d['charset_type']
        if 'dev_id' in d:
            o.dev_id = d['dev_id']
        if 'gateway_url' in d:
            o.gateway_url = d['gateway_url']
        if 'package_code_set' in d:
            o.package_code_set = d['package_code_set']
        if 'pid' in d:
            o.pid = d['pid']
        if 'signature_type' in d:
            o.signature_type = d['signature_type']
        if 'status' in d:
            o.status = d['status']
        if 'use_encrypt' in d:
            o.use_encrypt = d['use_encrypt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SignContentBodyRequest(object):

    def __init__(self):
        self._file_name = None
        self._plain_content = None
        self._sha_content = None

    @property
    def file_name(self):
        return self._file_name

    @file_name.setter
    def file_name(self, value):
        self._file_name = value
    @property
    def plain_content(self):
        return self._plain_content

    @plain_content.setter
    def plain_content(self, value):
        self._plain_content = value
    @property
    def sha_content(self):
        return self._sha_content

    @sha_content.setter
    def sha_content(self, value):
        self._sha_content = value


    def to_alipay_dict(self):
        params = dict()
        if self.file_name:
            if hasattr(self.file_name, 'to_alipay_dict'):
                params['file_name'] = self.file_name.to_alipay_dict()
            else:
                params['file_name'] = self.file_name
        if self.plain_content:
            if hasattr(self.plain_content, 'to_alipay_dict'):
                params['plain_content'] = self.plain_content.to_alipay_dict()
            else:
                params['plain_content'] = self.plain_content
        if self.sha_content:
            if hasattr(self.sha_content, 'to_alipay_dict'):
                params['sha_content'] = self.sha_content.to_alipay_dict()
            else:
                params['sha_content'] = self.sha_content
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignContentBodyRequest()
        if 'file_name' in d:
            o.file_name = d['file_name']
        if 'plain_content' in d:
            o.plain_content = d['plain_content']
        if 'sha_content' in d:
            o.sha_content = d['sha_content']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DataFile(object):

    def __init__(self):
        self._access_url = None
        self._data_type = None

    @property
    def access_url(self):
        return self._access_url

    @access_url.setter
    def access_url(self, value):
        self._access_url = value
    @property
    def data_type(self):
        return self._data_type

    @data_type.setter
    def data_type(self, value):
        self._data_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.access_url:
            if hasattr(self.access_url, 'to_alipay_dict'):
                params['access_url'] = self.access_url.to_alipay_dict()
            else:
                params['access_url'] = self.access_url
        if self.data_type:
            if hasattr(self.data_type, 'to_alipay_dict'):
                params['data_type'] = self.data_type.to_alipay_dict()
            else:
                params['data_type'] = self.data_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DataFile()
        if 'access_url' in d:
            o.access_url = d['access_url']
        if 'data_type' in d:
            o.data_type = d['data_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityRiskPolicyConfirmModel(object):

    def __init__(self):
        self._confirm_params = None
        self._security_id = None

    @property
    def confirm_params(self):
        return self._confirm_params

    @confirm_params.setter
    def confirm_params(self, value):
        self._confirm_params = value
    @property
    def security_id(self):
        return self._security_id

    @security_id.setter
    def security_id(self, value):
        self._security_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.confirm_params:
            if hasattr(self.confirm_params, 'to_alipay_dict'):
                params['confirm_params'] = self.confirm_params.to_alipay_dict()
            else:
                params['confirm_params'] = self.confirm_params
        if self.security_id:
            if hasattr(self.security_id, 'to_alipay_dict'):
                params['security_id'] = self.security_id.to_alipay_dict()
            else:
                params['security_id'] = self.security_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityRiskPolicyConfirmModel()
        if 'confirm_params' in d:
            o.confirm_params = d['confirm_params']
        if 'security_id' in d:
            o.security_id = d['security_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMerchantPayforprivilegePromconfigureQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMerchantPayforprivilegePromconfigureQueryResponse, self).__init__()
        self._enabled_shop_list = None
        self._exclude_item_ids = None
        self._support_item_ids = None

    @property
    def enabled_shop_list(self):
        return self._enabled_shop_list

    @enabled_shop_list.setter
    def enabled_shop_list(self, value):
        if isinstance(value, list):
            self._enabled_shop_list = list()
            for i in value:
                self._enabled_shop_list.append(i)
    @property
    def exclude_item_ids(self):
        return self._exclude_item_ids

    @exclude_item_ids.setter
    def exclude_item_ids(self, value):
        if isinstance(value, list):
            self._exclude_item_ids = list()
            for i in value:
                self._exclude_item_ids.append(i)
    @property
    def support_item_ids(self):
        return self._support_item_ids

    @support_item_ids.setter
    def support_item_ids(self, value):
        if isinstance(value, list):
            self._support_item_ids = list()
            for i in value:
                self._support_item_ids.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayMerchantPayforprivilegePromconfigureQueryResponse, self).parse_response_content(response_content)
        if 'enabled_shop_list' in response:
            self.enabled_shop_list = response['enabled_shop_list']
        if 'exclude_item_ids' in response:
            self.exclude_item_ids = response['exclude_item_ids']
        if 'support_item_ids' in response:
            self.support_item_ids = response['support_item_ids']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.KeyWordInfo import KeyWordInfo


class AlipayOpenSearchAppkeywordQuerystatusResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenSearchAppkeywordQuerystatusResponse, self).__init__()
        self._key_words = None

    @property
    def key_words(self):
        return self._key_words

    @key_words.setter
    def key_words(self, value):
        if isinstance(value, list):
            self._key_words = list()
            for i in value:
                if isinstance(i, KeyWordInfo):
                    self._key_words.append(i)
                else:
                    self._key_words.append(KeyWordInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenSearchAppkeywordQuerystatusResponse, self).parse_response_content(response_content)
        if 'key_words' in response:
            self.key_words = response['key_words']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoMycarViolationVehicleQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoMycarViolationVehicleQueryResponse, self).__init__()
        self._engine_no = None
        self._vi_id = None
        self._vi_number = None
        self._vin_no = None

    @property
    def engine_no(self):
        return self._engine_no

    @engine_no.setter
    def engine_no(self, value):
        self._engine_no = value
    @property
    def vi_id(self):
        return self._vi_id

    @vi_id.setter
    def vi_id(self, value):
        self._vi_id = value
    @property
    def vi_number(self):
        return self._vi_number

    @vi_number.setter
    def vi_number(self, value):
        self._vi_number = value
    @property
    def vin_no(self):
        return self._vin_no

    @vin_no.setter
    def vin_no(self, value):
        self._vin_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoMycarViolationVehicleQueryResponse, self).parse_response_content(response_content)
        if 'engine_no' in response:
            self.engine_no = response['engine_no']
        if 'vi_id' in response:
            self.vi_id = response['vi_id']
        if 'vi_number' in response:
            self.vi_number = response['vi_number']
        if 'vin_no' in response:
            self.vin_no = response['vin_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SlmCaseErrorInfo(object):

    def __init__(self):
        self._error_desc = None
        self._error_format = None
        self._error_info = None
        self._error_type = None

    @property
    def error_desc(self):
        return self._error_desc

    @error_desc.setter
    def error_desc(self, value):
        self._error_desc = value
    @property
    def error_format(self):
        return self._error_format

    @error_format.setter
    def error_format(self, value):
        self._error_format = value
    @property
    def error_info(self):
        return self._error_info

    @error_info.setter
    def error_info(self, value):
        self._error_info = value
    @property
    def error_type(self):
        return self._error_type

    @error_type.setter
    def error_type(self, value):
        self._error_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.error_desc:
            if hasattr(self.error_desc, 'to_alipay_dict'):
                params['error_desc'] = self.error_desc.to_alipay_dict()
            else:
                params['error_desc'] = self.error_desc
        if self.error_format:
            if hasattr(self.error_format, 'to_alipay_dict'):
                params['error_format'] = self.error_format.to_alipay_dict()
            else:
                params['error_format'] = self.error_format
        if self.error_info:
            if hasattr(self.error_info, 'to_alipay_dict'):
                params['error_info'] = self.error_info.to_alipay_dict()
            else:
                params['error_info'] = self.error_info
        if self.error_type:
            if hasattr(self.error_type, 'to_alipay_dict'):
                params['error_type'] = self.error_type.to_alipay_dict()
            else:
                params['error_type'] = self.error_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SlmCaseErrorInfo()
        if 'error_desc' in d:
            o.error_desc = d['error_desc']
        if 'error_format' in d:
            o.error_format = d['error_format']
        if 'error_info' in d:
            o.error_info = d['error_info']
        if 'error_type' in d:
            o.error_type = d['error_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEcConsumeDetailQueryModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._enterprise_id = None
        self._pay_no = None
        self._query_options = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def pay_no(self):
        return self._pay_no

    @pay_no.setter
    def pay_no(self, value):
        self._pay_no = value
    @property
    def query_options(self):
        return self._query_options

    @query_options.setter
    def query_options(self, value):
        if isinstance(value, list):
            self._query_options = list()
            for i in value:
                self._query_options.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.enterprise_id:
            if hasattr(self.enterprise_id, 'to_alipay_dict'):
                params['enterprise_id'] = self.enterprise_id.to_alipay_dict()
            else:
                params['enterprise_id'] = self.enterprise_id
        if self.pay_no:
            if hasattr(self.pay_no, 'to_alipay_dict'):
                params['pay_no'] = self.pay_no.to_alipay_dict()
            else:
                params['pay_no'] = self.pay_no
        if self.query_options:
            if isinstance(self.query_options, list):
                for i in range(0, len(self.query_options)):
                    element = self.query_options[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.query_options[i] = element.to_alipay_dict()
            if hasattr(self.query_options, 'to_alipay_dict'):
                params['query_options'] = self.query_options.to_alipay_dict()
            else:
                params['query_options'] = self.query_options
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEcConsumeDetailQueryModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'enterprise_id' in d:
            o.enterprise_id = d['enterprise_id']
        if 'pay_no' in d:
            o.pay_no = d['pay_no']
        if 'query_options' in d:
            o.query_options = d['query_options']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AllocDetailDTO(object):

    def __init__(self):
        self._account_id = None
        self._alloc_amount = None
        self._alloc_error_code = None
        self._alloc_error_msg = None
        self._alloc_status = None
        self._alloc_time = None
        self._detail_id = None
        self._fund_plan_id = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def alloc_amount(self):
        return self._alloc_amount

    @alloc_amount.setter
    def alloc_amount(self, value):
        self._alloc_amount = value
    @property
    def alloc_error_code(self):
        return self._alloc_error_code

    @alloc_error_code.setter
    def alloc_error_code(self, value):
        self._alloc_error_code = value
    @property
    def alloc_error_msg(self):
        return self._alloc_error_msg

    @alloc_error_msg.setter
    def alloc_error_msg(self, value):
        self._alloc_error_msg = value
    @property
    def alloc_status(self):
        return self._alloc_status

    @alloc_status.setter
    def alloc_status(self, value):
        self._alloc_status = value
    @property
    def alloc_time(self):
        return self._alloc_time

    @alloc_time.setter
    def alloc_time(self, value):
        self._alloc_time = value
    @property
    def detail_id(self):
        return self._detail_id

    @detail_id.setter
    def detail_id(self, value):
        self._detail_id = value
    @property
    def fund_plan_id(self):
        return self._fund_plan_id

    @fund_plan_id.setter
    def fund_plan_id(self, value):
        self._fund_plan_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.alloc_amount:
            if hasattr(self.alloc_amount, 'to_alipay_dict'):
                params['alloc_amount'] = self.alloc_amount.to_alipay_dict()
            else:
                params['alloc_amount'] = self.alloc_amount
        if self.alloc_error_code:
            if hasattr(self.alloc_error_code, 'to_alipay_dict'):
                params['alloc_error_code'] = self.alloc_error_code.to_alipay_dict()
            else:
                params['alloc_error_code'] = self.alloc_error_code
        if self.alloc_error_msg:
            if hasattr(self.alloc_error_msg, 'to_alipay_dict'):
                params['alloc_error_msg'] = self.alloc_error_msg.to_alipay_dict()
            else:
                params['alloc_error_msg'] = self.alloc_error_msg
        if self.alloc_status:
            if hasattr(self.alloc_status, 'to_alipay_dict'):
                params['alloc_status'] = self.alloc_status.to_alipay_dict()
            else:
                params['alloc_status'] = self.alloc_status
        if self.alloc_time:
            if hasattr(self.alloc_time, 'to_alipay_dict'):
                params['alloc_time'] = self.alloc_time.to_alipay_dict()
            else:
                params['alloc_time'] = self.alloc_time
        if self.detail_id:
            if hasattr(self.detail_id, 'to_alipay_dict'):
                params['detail_id'] = self.detail_id.to_alipay_dict()
            else:
                params['detail_id'] = self.detail_id
        if self.fund_plan_id:
            if hasattr(self.fund_plan_id, 'to_alipay_dict'):
                params['fund_plan_id'] = self.fund_plan_id.to_alipay_dict()
            else:
                params['fund_plan_id'] = self.fund_plan_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AllocDetailDTO()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'alloc_amount' in d:
            o.alloc_amount = d['alloc_amount']
        if 'alloc_error_code' in d:
            o.alloc_error_code = d['alloc_error_code']
        if 'alloc_error_msg' in d:
            o.alloc_error_msg = d['alloc_error_msg']
        if 'alloc_status' in d:
            o.alloc_status = d['alloc_status']
        if 'alloc_time' in d:
            o.alloc_time = d['alloc_time']
        if 'detail_id' in d:
            o.detail_id = d['detail_id']
        if 'fund_plan_id' in d:
            o.fund_plan_id = d['fund_plan_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PayForPrivilegeRechargeCardUseLog(object):

    def __init__(self):
        self._amount = None
        self._benefit = None
        self._biz_date = None
        self._biz_type = None
        self._order_id = None
        self._principal = None
        self._trade_no = None
        self._user_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def benefit(self):
        return self._benefit

    @benefit.setter
    def benefit(self, value):
        self._benefit = value
    @property
    def biz_date(self):
        return self._biz_date

    @biz_date.setter
    def biz_date(self, value):
        self._biz_date = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def principal(self):
        return self._principal

    @principal.setter
    def principal(self, value):
        self._principal = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.benefit:
            if hasattr(self.benefit, 'to_alipay_dict'):
                params['benefit'] = self.benefit.to_alipay_dict()
            else:
                params['benefit'] = self.benefit
        if self.biz_date:
            if hasattr(self.biz_date, 'to_alipay_dict'):
                params['biz_date'] = self.biz_date.to_alipay_dict()
            else:
                params['biz_date'] = self.biz_date
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.principal:
            if hasattr(self.principal, 'to_alipay_dict'):
                params['principal'] = self.principal.to_alipay_dict()
            else:
                params['principal'] = self.principal
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PayForPrivilegeRechargeCardUseLog()
        if 'amount' in d:
            o.amount = d['amount']
        if 'benefit' in d:
            o.benefit = d['benefit']
        if 'biz_date' in d:
            o.biz_date = d['biz_date']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'principal' in d:
            o.principal = d['principal']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ItemConsultRequest import ItemConsultRequest


class AlipayCommerceVoucherResultConsultModel(object):

    def __init__(self):
        self._isv_pid = None
        self._item_consult_list = None
        self._merchant_pid = None
        self._order_amount = None
        self._scene_code = None

    @property
    def isv_pid(self):
        return self._isv_pid

    @isv_pid.setter
    def isv_pid(self, value):
        self._isv_pid = value
    @property
    def item_consult_list(self):
        return self._item_consult_list

    @item_consult_list.setter
    def item_consult_list(self, value):
        if isinstance(value, ItemConsultRequest):
            self._item_consult_list = value
        else:
            self._item_consult_list = ItemConsultRequest.from_alipay_dict(value)
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        self._order_amount = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.isv_pid:
            if hasattr(self.isv_pid, 'to_alipay_dict'):
                params['isv_pid'] = self.isv_pid.to_alipay_dict()
            else:
                params['isv_pid'] = self.isv_pid
        if self.item_consult_list:
            if hasattr(self.item_consult_list, 'to_alipay_dict'):
                params['item_consult_list'] = self.item_consult_list.to_alipay_dict()
            else:
                params['item_consult_list'] = self.item_consult_list
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.order_amount:
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = self.order_amount.to_alipay_dict()
            else:
                params['order_amount'] = self.order_amount
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceVoucherResultConsultModel()
        if 'isv_pid' in d:
            o.isv_pid = d['isv_pid']
        if 'item_consult_list' in d:
            o.item_consult_list = d['item_consult_list']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'order_amount' in d:
            o.order_amount = d['order_amount']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditUserRoleCreateModel(object):

    def __init__(self):
        self._entity_code = None
        self._entity_code_open_id = None
        self._entity_name = None
        self._entity_type = None
        self._ext_data = None
        self._scene_type = None

    @property
    def entity_code(self):
        return self._entity_code

    @entity_code.setter
    def entity_code(self, value):
        self._entity_code = value
    @property
    def entity_code_open_id(self):
        return self._entity_code_open_id

    @entity_code_open_id.setter
    def entity_code_open_id(self, value):
        self._entity_code_open_id = value
    @property
    def entity_name(self):
        return self._entity_name

    @entity_name.setter
    def entity_name(self, value):
        self._entity_name = value
    @property
    def entity_type(self):
        return self._entity_type

    @entity_type.setter
    def entity_type(self, value):
        self._entity_type = value
    @property
    def ext_data(self):
        return self._ext_data

    @ext_data.setter
    def ext_data(self, value):
        self._ext_data = value
    @property
    def scene_type(self):
        return self._scene_type

    @scene_type.setter
    def scene_type(self, value):
        self._scene_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.entity_code:
            if hasattr(self.entity_code, 'to_alipay_dict'):
                params['entity_code'] = self.entity_code.to_alipay_dict()
            else:
                params['entity_code'] = self.entity_code
        if self.entity_code_open_id:
            if hasattr(self.entity_code_open_id, 'to_alipay_dict'):
                params['entity_code_open_id'] = self.entity_code_open_id.to_alipay_dict()
            else:
                params['entity_code_open_id'] = self.entity_code_open_id
        if self.entity_name:
            if hasattr(self.entity_name, 'to_alipay_dict'):
                params['entity_name'] = self.entity_name.to_alipay_dict()
            else:
                params['entity_name'] = self.entity_name
        if self.entity_type:
            if hasattr(self.entity_type, 'to_alipay_dict'):
                params['entity_type'] = self.entity_type.to_alipay_dict()
            else:
                params['entity_type'] = self.entity_type
        if self.ext_data:
            if hasattr(self.ext_data, 'to_alipay_dict'):
                params['ext_data'] = self.ext_data.to_alipay_dict()
            else:
                params['ext_data'] = self.ext_data
        if self.scene_type:
            if hasattr(self.scene_type, 'to_alipay_dict'):
                params['scene_type'] = self.scene_type.to_alipay_dict()
            else:
                params['scene_type'] = self.scene_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditUserRoleCreateModel()
        if 'entity_code' in d:
            o.entity_code = d['entity_code']
        if 'entity_code_open_id' in d:
            o.entity_code_open_id = d['entity_code_open_id']
        if 'entity_name' in d:
            o.entity_name = d['entity_name']
        if 'entity_type' in d:
            o.entity_type = d['entity_type']
        if 'ext_data' in d:
            o.ext_data = d['ext_data']
        if 'scene_type' in d:
            o.scene_type = d['scene_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PlateInfoForYiCai(object):

    def __init__(self):
        self._category = None
        self._id = None
        self._plate_name = None
        self._symbol_name = None

    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def plate_name(self):
        return self._plate_name

    @plate_name.setter
    def plate_name(self, value):
        self._plate_name = value
    @property
    def symbol_name(self):
        return self._symbol_name

    @symbol_name.setter
    def symbol_name(self, value):
        if isinstance(value, list):
            self._symbol_name = list()
            for i in value:
                self._symbol_name.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.plate_name:
            if hasattr(self.plate_name, 'to_alipay_dict'):
                params['plate_name'] = self.plate_name.to_alipay_dict()
            else:
                params['plate_name'] = self.plate_name
        if self.symbol_name:
            if isinstance(self.symbol_name, list):
                for i in range(0, len(self.symbol_name)):
                    element = self.symbol_name[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.symbol_name[i] = element.to_alipay_dict()
            if hasattr(self.symbol_name, 'to_alipay_dict'):
                params['symbol_name'] = self.symbol_name.to_alipay_dict()
            else:
                params['symbol_name'] = self.symbol_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PlateInfoForYiCai()
        if 'category' in d:
            o.category = d['category']
        if 'id' in d:
            o.id = d['id']
        if 'plate_name' in d:
            o.plate_name = d['plate_name']
        if 'symbol_name' in d:
            o.symbol_name = d['symbol_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniInneraccountPidQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniInneraccountPidQueryResponse, self).__init__()
        self._pid = None

    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniInneraccountPidQueryResponse, self).parse_response_content(response_content)
        if 'pid' in response:
            self.pid = response['pid']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditUserRoleQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditUserRoleQueryResponse, self).__init__()
        self._cert_name = None
        self._cert_no = None
        self._cert_type = None
        self._ip_id = None
        self._ip_role_id = None
        self._ip_type = None
        self._site = None
        self._site_login_id = None
        self._site_user_id = None

    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def ip_type(self):
        return self._ip_type

    @ip_type.setter
    def ip_type(self, value):
        self._ip_type = value
    @property
    def site(self):
        return self._site

    @site.setter
    def site(self, value):
        self._site = value
    @property
    def site_login_id(self):
        return self._site_login_id

    @site_login_id.setter
    def site_login_id(self, value):
        self._site_login_id = value
    @property
    def site_user_id(self):
        return self._site_user_id

    @site_user_id.setter
    def site_user_id(self, value):
        self._site_user_id = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditUserRoleQueryResponse, self).parse_response_content(response_content)
        if 'cert_name' in response:
            self.cert_name = response['cert_name']
        if 'cert_no' in response:
            self.cert_no = response['cert_no']
        if 'cert_type' in response:
            self.cert_type = response['cert_type']
        if 'ip_id' in response:
            self.ip_id = response['ip_id']
        if 'ip_role_id' in response:
            self.ip_role_id = response['ip_role_id']
        if 'ip_type' in response:
            self.ip_type = response['ip_type']
        if 'site' in response:
            self.site = response['site']
        if 'site_login_id' in response:
            self.site_login_id = response['site_login_id']
        if 'site_user_id' in response:
            self.site_user_id = response['site_user_id']
